@@ -1,6 +1,6 @@
 make.asr.marginal.geosse <- function(lik, ...) {
   e <- environment(lik)
-  do.asr <- make.do.asr.marginal(e$all.branches, e$rootfunc)
+  do.asr <- make.do.asr.marginal(e$all_branches, e$rootfunc)
   asr <- function(pars, nodes=NULL, condition.surv=TRUE,
                   root=ROOT.FLAT, root.p=NULL, ...) {
     check.pars.nonnegative(pars, 7)    
