@@ -1,13 +1,16 @@
 *----------------------------------------------------------------------|
       subroutine DSEXPV( n, m, t, v, w, tol, anorm, ia, ja, a, nz,
-     .                   wsp,lwsp, iwsp,liwsp, itrace,iflag, scal)
+     .     wsp,lwsp, iwsp,liwsp, cwsp,lcwsp,
+     .     itrace, iflag, scal)
 
       implicit none
-      integer n, m, lwsp, liwsp, itrace, iflag, iwsp(liwsp), nz, nzmax
+      integer n, m, lwsp, liwsp, lcwsp, itrace, iflag, iwsp(liwsp), nz,
+     .     nzmax
       parameter( nzmax=139301 )
       integer ia(nzmax), ja(nzmax)
       double precision t, tol, anorm, v(n), w(n), wsp(lwsp), a(nzmax),
      .     scal
+      complex(kind=kind(0.0d0)) cwsp(lcwsp)
 
 *-----Purpose----------------------------------------------------------|
 *
@@ -311,7 +314,7 @@ C     where this is skipped, this should not matter (happy breakdown).
             wsp(iexph+i-1) = 0.0d0
          enddo
          wsp(iexph) = 1.0d0
-         call DNCHBV(mx,sgn*t_step,wsp(ih),mh,wsp(iexph),wsp(ifree+mx))
+         call DNCHBV(mx,sgn*t_step,wsp(ih),mh,wsp(iexph),cwsp(ifree+mx))
       endif
 
       continue
